# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class SshKey(pulumi.CustomResource):
    created: pulumi.Output[str]
    label: pulumi.Output[str]
    """
    A label for the SSH Key.
    """
    ssh_key: pulumi.Output[str]
    """
    The public SSH Key, which is used to authenticate to the root user of the Linodes you deploy.
    """
    def __init__(__self__, resource_name, opts=None, label=None, ssh_key=None, __name__=None, __opts__=None):
        """
        Provides a Linode SSH Key resource.  This can be used to create, modify, and delete Linodes SSH Keys.  Managed SSH Keys allow instances to be created with a list of Linode usernames, whose SSH keys will be automatically applied to the root account's `~/.ssh/authorized_keys` file.
        For more information, see the [Linode APIv4 docs](https://developers.linode.com/api/v4#operation/getSSHKeys).
        
        ## Attributes
        
        This resource exports the following attributes:
        
        * `created` - The date this SSH Key was created.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] label: A label for the SSH Key.
        :param pulumi.Input[str] ssh_key: The public SSH Key, which is used to authenticate to the root user of the Linodes you deploy.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if label is None:
            raise TypeError("Missing required property 'label'")
        __props__['label'] = label

        if ssh_key is None:
            raise TypeError("Missing required property 'ssh_key'")
        __props__['ssh_key'] = ssh_key

        __props__['created'] = None

        super(SshKey, __self__).__init__(
            'linode:index/sshKey:SshKey',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

